import xfox
import discord
import Amisynth.utils as utils


@xfox.addfunc(xfox.funcs)
async def removeButtons(message_id:int=None, *args, **kwargs):
    """
    Elimina todos los botones del mensaje especificado.
    - Si no se proporciona message_id, usa el mensaje actual del contexto.
    - Conserva otros componentes (como select menus).
    """

    context = utils.ContextAmisynth()

    # Obtener el mensaje
    if message_id is None:
        message_id = context.message_id

        
    message  = await context.get_message_from_id(int(message_id))

    # Obtener vista actual
    view = discord.ui.View() if not message.components else discord.ui.View.from_message(message)

    # Filtrar todos los que NO sean botones
    new_view = discord.ui.View()
    for item in view.children:
        if not isinstance(item, discord.ui.Button):
            new_view.add_item(item)

    await message.edit(view=new_view)
    return ""



import xfox
import discord
import Amisynth.utils as utils

@xfox.addfunc(xfox.funcs)
async def setChannelVar(nombre=None, value=None, guild_id=None, channel_id=None, *args, **kwargs):
    """Establece una variable para un canal específico."""
    context = utils.ContextAmisynth()
    
    if nombre is None or value is None:
        raise ValueError(":x: Error, el nombre o el valor están vacíos en la función `$setChannelVar[?;?]`.")
    
    if guild_id is None:
        guild_id = context.guild_id

    if channel_id is None:
        channel_id = context.channel_id

    var = utils.VariableManager()
    
    # Establece el valor para el canal especificado
    var.set_value("channel", key=nombre, value=value, guild_id=guild_id, channel_id=channel_id)
    print("[DEBUG SETCHANNELVAR]white_check_mark: Variable `{nombre}` establecida con éxito para el canal.")
    return f""


import xfox

@xfox.addfunc(xfox.funcs)
async def checkContains(text, *phrases, **kwargs):
    """
    Verifica si el texto contiene alguna de las frases proporcionadas.
    Devuelve True si alguna frase está contenida en el texto, y False si no.

    :param text: El texto en el que buscar las frases.
    :param phrases: Las frases que se buscarán dentro del texto.
    :return: True si alguna frase está contenida en el texto, False si no.
    """
    
    # Verificar si alguna de las frases está en el texto
    for phrase in phrases:
        if phrase.lower() in text.lower():
            return True
    
    return False  # Si ninguna frase fue encontrada en el texto



import xfox
import Amisynth.utils as utils


@xfox.addfunc(xfox.funcs)
async def input(custom, *args, **kwargs):
    # Asegúrate de que kwargs contiene la interacción correcta
    interaction = kwargs.get('interaction')  # Asumiendo que se pasa 'interaction' en kwargs
    
    if interaction is None:
        raise ValueError("Interacción no encontrada.")

    # Acceder a los componentes (TextInput)
    inputs = interaction.data["components"][0]["components"]
    
    # Buscar el TextInput con custom_id específico
    for input_component in inputs:
        if input_component["custom_id"] == custom:  # Aquí se busca por custom_id
            return input_component["value"]
        
    print("[DEBUG INPUT] No se encontró el TextInput con el custom_id proporcionado")
    return ""




import xfox
from Amisynth.utils import options_slash

@xfox.addfunc(xfox.funcs, name="addSlashOption")
async def addSlashOption(nombre: str=None, description:str="..", tipo: str="Texto", requerido=False, retornar: bool = False, *args, **kwargs):
    """
    Agrega una opción para un slash command.

    - Evita nombres duplicados.
    - Si 'retornar' es True, retorna el nombre.

    Uso:
        $add_option[mensaje;Texto;true]
    """
    if nombre is None:
        raise ValueError(":x: Error en `$addSlashOption[?;..] esta vacio el primer argumento.`")

    # Verificar duplicado

    options_slash.append({
        "name_option": nombre,
        "type": tipo,
        "description": description,
        "required": requerido,
        "choices": []
    })

    if retornar:
        return nombre
    else: 
        return ""


import xfox
import json
from Amisynth.utils import json_storage

@xfox.addfunc(xfox.funcs)
async def jsonStringify(*args, **kwargs):
    try:
        return json.dumps(json_storage, ensure_ascii=False, separators=(',', ':'))
    except Exception as e:
        raise ValueError(f"Error al convertir JSON a string: {e}")
